@@ -1,4 +1,4 @@
-from . import Module, error
+from .init import Module, error
 
 
 class Distro(Module):
