@@ -1,6 +1,6 @@
 from setux.core import __version__
 
-from . import Module, info
+from .init import Module, info
 
 
 class Distro(Module):
